@@ -1,6 +1,10 @@
 
-""" ``validation`` package.
 """
+"""
+
+__version__ = '0.1.84'
+
+# flake8: noqa
 
 from wheezy.validation.mixin import ValidationMixin
 from wheezy.validation.model import try_update_model
